@@ -1098,32 +1098,12 @@ TC_OPTION(zoom,               'Z', "[W]x[H][,mode]",
 )
 TC_OPTION(zoom_filter,        0,   "filter",
                 "use given filter for -Z resizing [Lanczos3]",
-                if (strcasecmp(optarg, "bell") == 0) {
-                    vob->zoom_filter = TCV_ZOOM_BELL;
-                    zoom_filter = "Bell";
-                } else if (strcasecmp(optarg, "box") == 0) {
-                    vob->zoom_filter = TCV_ZOOM_BOX;
-                    zoom_filter = "Box";
-                } else if (strcasecmp(optarg, "b_spline") == 0) {
-                    vob->zoom_filter = TCV_ZOOM_B_SPLINE;
-                    zoom_filter = "B_spline";
-                } else if (strcasecmp(optarg, "hermite") == 0) {
-                    vob->zoom_filter = TCV_ZOOM_HERMITE;
-                    zoom_filter = "Hermite";
-                } else if (strcasecmp(optarg, "lanczos3") == 0) {
-                    vob->zoom_filter = TCV_ZOOM_LANCZOS3;
-                    zoom_filter = "Lanczos3";
-                } else if (strcasecmp(optarg, "mitchell") == 0) {
-                    vob->zoom_filter = TCV_ZOOM_MITCHELL;
-                    zoom_filter = "Mitchell";
-                } else if (strcasecmp(optarg, "triangle") == 0) {
-                    vob->zoom_filter = TCV_ZOOM_TRIANGLE;
-                    zoom_filter = "Triangle";
-                } else {
+                vob->zoom_filter = tcv_zoom_filter_from_string(optarg);
+		if (vob->zoom_filter == TCV_ZOOM_NULL) {
                     tc_error("invalid argument for --zoom_filter\n"
                              "filter must be one of:\n"
                              "   bell box b_spline hermite lanczos3"
-                             " mitchell triangle");
+                             " mitchell triangle cubic_keys4 sinc8");
                     goto short_usage;
                 }
 )
@@ -1286,14 +1266,17 @@ TC_OPTION(filter,             'J', "f1[,f2...]",
                 int newlen;
                 if (*optarg == '-')
                     goto short_usage;
-                newlen = size_plugstr + 1 + strlen(optarg) + 1;  // , and \0
+                newlen = size_plugstr + strlen(optarg) + 1;  // \0
+                if (size_plugstr) // it's an append...
+                    newlen++; // ... so add the and ',' separator
                 plugins_string = tc_realloc(plugins_string, newlen);
                 if (!plugins_string)
                     return 0;
                 snprintf(plugins_string + size_plugstr,
                          newlen - size_plugstr,
                          "%s%s", size_plugstr ? "," : "", optarg);
-                size_plugstr = newlen;
+                size_plugstr = newlen - 1;
+                // cut the \0 for the next append (if any)
 )
 TC_OPTION(quality,            'Q', "enc[,dec]",
                 "encoding[,decoding] quality (0=fastest-5=best) [5,5]",
@@ -1448,7 +1431,7 @@ TC_OPTION(autosplit,          'W', "n,m[,file]",
                            &vob->vob_chunk_max, vob_logfile) < 2
                  || vob->vob_chunk < 0
                  || vob->vob_chunk_max <= 0
-                 || vob->vob_chunk >= vob->vob_chunk_max
+                 || vob->vob_chunk >= vob->vob_chunk_max + 1
                 ) {
                     tc_error("Invalid parameter for -W/--autosplit");
                     goto short_usage;
